==> pwmd-2.17.tar.gz: pwmd-2.17/src/misc.h <==
/* vim:tw=78:ts=8:sw=4:set ft=c:  */
/*
    Copyright (C) 2006-2010 Ben Kibbey <bjk@luxsci.net>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02110-1301  USA
*/
#ifndef MISC_H
#define MISC_H

gint get_key_file_integer(const gchar *section, const gchar *what);

#define log_write0 log_write

#define log_write1(...) { \
    if (get_key_file_integer("global", "log_level") >= 1) \
	log_write(__VA_ARGS__); \
    }

#define log_write2(...) { \
    if (get_key_file_integer("global", "log_level") >= 2) \
	log_write(__VA_ARGS__); \
    }


typedef enum {
    OPT_NOARG,
    OPT_ARG,
    OPT_OPTARG,
} option_type_t;

struct argv_s {
    const gchar *opt;
    option_type_t type;
    gpg_error_t (*func)(gpointer data, gpointer value);
};

gpg_error_t parse_options(gchar **line, struct argv_s *args[], gpointer data);
gboolean strv_printf(gchar ***array, const gchar *fmt, ...);
gchar **strvcatv(gchar **dst, gchar **src);
gboolean valid_filename(const gchar *filename);
gchar *print_fmt(gchar *buf, gsize len, const char *fmt, ...);
gchar *expand_homedir(gchar *str);
gboolean contains_whitespace(const gchar *str);
gchar *strip_char(gchar *str, gchar c);
gchar *tohex(const guchar *str, gsize len);
gchar **split_input_line(gchar *str, gchar *delim, gint n);
void log_write(const gchar *fmt, ...);

#endif

==> pwmd-2.18.tar.gz: pwmd-2.18/src/misc.h <==
/* vim:tw=78:ts=8:sw=4:set ft=c:  */
/*
    Copyright (C) 2006-2010 Ben Kibbey <bjk@luxsci.net>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02110-1301  USA
*/
#ifndef MISC_H
#define MISC_H

gint get_key_file_integer(const gchar *section, const gchar *what);

#define log_write0 log_write

#define log_write1(...) { \
    if (get_key_file_integer("global", "log_level") >= 1) \
	log_write(__VA_ARGS__); \
    }

#define log_write2(...) { \
    if (get_key_file_integer("global", "log_level") >= 2) \
	log_write(__VA_ARGS__); \
    }


typedef enum {
    OPTION_TYPE_NOARG,
    OPTION_TYPE_ARG,
    OPTION_TYPE_OPTARG,
} option_type_t;

struct argv_s {
    const gchar *opt;
    option_type_t type;
    gpg_error_t (*func)(gpointer data, gpointer value);
};

gpg_error_t parse_options(gchar **line, struct argv_s *args[], gpointer data);
gboolean strv_printf(gchar ***array, const gchar *fmt, ...);
gchar **strvcatv(gchar **dst, gchar **src);
gboolean valid_filename(const gchar *filename);
gchar *print_fmt(gchar *buf, gsize len, const char *fmt, ...);
gchar *expand_homedir(gchar *str);
gchar **split_input_line(gchar *str, gchar *delim, gint n);

#endif
